<?php

/**
 * In this file we will create everything we need for a metabox in our CPT Form
 */

/**
 * Class for creating a metabox
 */
class MWP_Form_Metabox {
 
    /**
     * Constructor.
     */
    public function __construct() {
        if ( is_admin() ) {
            add_action( 'load-post.php',     array( $this, 'init_metabox' ) );
            add_action( 'load-post-new.php', array( $this, 'init_metabox' ) );
        }
 
    }
 
    /**
     * Meta box initialization.
     */
    public function init_metabox() {
        add_action( 'add_meta_boxes', array( $this, 'add_metabox'  )        );
        add_action( 'save_post',      array( $this, 'save_metabox' ), 10, 2 );
    }
 
    /**
     * Adds the meta box.
     */
    public function add_metabox() {
        add_meta_box(
            'form-metabox',
            __( 'Information', 'mwp' ),
            array( $this, 'render_metabox' ),
            'mwp_form',
            'advanced',
            'default'
        );
 
    }
 
    /**
     * Renders the meta box.
     */
    public function render_metabox( $post ) {
        // Add nonce for security and authentication.
        wp_nonce_field( 'form_nonce_save', 'form_nonce' );
        $redirect_url  = get_post_meta( $post->ID, 'mwp_mailchimp_list_redirect', true );
        $list_id_saved = get_post_meta( $post->ID, 'mwp_mailchimp_list_id', true );
        
        $lists = mwp_get_mailchimp_lists();  
        ?>
        <table class="form-table">
            <tr>
                <th>
                    <?php _e( 'List', 'mwp'); ?>
                </th>
                <td>
                    <?php 

                        if( count( $lists ) > 0 ) { 
                            echo '<select name="mwp_mailchimp_list_id">';
                            
                            foreach ( $lists as $list_id => $list_title) {
                                echo '<option value="' . $list_id . '" ' . selected( $list_id_saved, $list_id, false ) . '>' . $list_title . '</option>';
                            }

                            echo '</select>';
                    ?> 
                    <?php } else { ?>
                        <p><?php _e( "You don't have any lists yet. Create one in Mailchimp", "mwp" ); ?></p>
                    <?php } ?>
                </td>
            </tr>

            <tr>
                <th>
                    <?php _e( 'Redirect URL', 'mwp'); ?>
                </th>
                <td>
                    <input type="url" name="mwp_mailchimp_list_redirect" placeholder="<?php _e( 'Enter an URL (http://...)', 'mwp' ); ?>" value="<?php echo $redirect_url; ?>"
                </td>
            </tr>

        </table>
        <?php
    }
 
    /**
     * Handles saving the meta box.
     *
     * @param int     $post_id Post ID.
     * @param WP_Post $post    Post object.
     * @return null
     */
    public function save_metabox( $post_id, $post ) {
        // Add nonce for security and authentication.
        $nonce_name   = isset( $_POST['form_nonce'] ) ? $_POST['form_nonce'] : '';
        $nonce_action = 'form_nonce_save';
 
        // Check if nonce is set.
        if ( ! isset( $nonce_name ) ) {
            return;
        }
 
        // Check if nonce is valid.
        if ( ! wp_verify_nonce( $nonce_name, $nonce_action ) ) {
            return;
        }
 
        // Check if user has permissions to save data.
        if ( ! current_user_can( 'edit_post', $post_id ) ) {
            return;
        }
 
        // Check if not an autosave.
        if ( wp_is_post_autosave( $post_id ) ) {
            return;
        }
 
        // Check if not a revision.
        if ( wp_is_post_revision( $post_id ) ) {
            return;
        }

        if( isset( $_POST[ 'mwp_mailchimp_list_id' ] ) ) {
            update_post_meta( $post_id, 'mwp_mailchimp_list_id', $_POST[ 'mwp_mailchimp_list_id' ] );
        }

        if( isset( $_POST[ 'mwp_mailchimp_list_redirect' ] ) ) {
            update_post_meta( $post_id, 'mwp_mailchimp_list_redirect', esc_url_raw( $_POST[ 'mwp_mailchimp_list_redirect' ], array( 'http', 'https') ) );
        }

    }
}