<?php

/**
 * MWP Widget to show the form
 */

class MWP_Widget extends WP_Widget {
 
    /**
     * Register widget with WordPress.
     */
    public function __construct() {
        parent::__construct(
            'mailchimp-form', // Base ID
            'MailChimp Subscription Form', // Name
            array( 'description' => __( 'Widget for creating forms', 'mwp' ), ) // Args
        );
    }
 
    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget( $args, $instance ) {
        extract( $args );
        $title = apply_filters( 'widget_title', $instance['title'] );
        $text = $instance['text'];
        $form_id = $instance['form_id']; 
        $form_args = array();

        if( $form_id == '' ) {
            return;
        }

        echo $before_widget;
        echo '<div class="mailchimp-form">';
        if ( ! empty( $title ) ) {
            echo $before_title . $title . $after_title;
        }
        if ( ! empty( $text ) ) { 
            echo '<p>' . $text . '</p>';
        }
 		
 			mwp_render_form( $form_id );

        echo '</div>';
        echo $after_widget;
    }
 
    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param array $instance Previously saved values from database.
     */
    public function form( $instance ) {
    	
        $text = isset( $instance['text'] ) ? $instance['text'] : '';
        
        $forms = mwp_get_all_forms();
        $current_form = isset( $instance['form_id'] ) ? $instance['form_id'] : '';

        if ( isset( $instance[ 'title' ] ) ) {
            $title = $instance[ 'title' ];
        }
        else {
            $title = __( 'New title', 'text_domain' );
        }

        ?>
        <p>
            <label for="<?php echo $this->get_field_name( 'title' ); ?>"><?php _e( 'Title:' ); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>
        <p>
            <label for="<?php echo $this->get_field_name( 'text' ); ?>"><?php _e( 'Text:' ); ?></label>
            <textarea  class="widefat" id="<?php echo $this->get_field_id( 'text' ); ?>" name="<?php echo $this->get_field_name( 'text' ); ?>"><?php echo esc_attr( $text ); ?></textarea>
        </p>
        <p>
            <label for="<?php echo $this->get_field_name( 'form_id' ); ?>"><?php _e( 'Form:' ); ?></label>
            <?php if( count( $forms ) > 0 ) { ?>
            <select id="<?php echo $this->get_field_id( 'form_id' ); ?>" name="<?php echo $this->get_field_name( 'form_id' ); ?>" >
                <?php foreach ($forms as $form) {
                    echo '<option ' . selected( $current_form, $form->ID, false ) .  ' value="' . $form->ID . '">' . $form->post_title .'</option>';
                } ?>
            </select>
            <?php } else { _e( 'Please create a form to use this widget', 'mwp' ); } ?>
       </p>

        <?php
    }
 
    /**
     * Sanitize widget form values as they are saved.
     *
     * @see WP_Widget::update()
     *
     * @param array $new_instance Values just sent to be saved.
     * @param array $old_instance Previously saved values from database.
     *
     * @return array Updated safe values to be saved.
     */
    public function update( $new_instance, $old_instance ) {
        $instance = array();
        $instance['title'] = ( !empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['text'] = ( !empty( $new_instance['text'] ) ) ? strip_tags( $new_instance['text'] ) : '';
        $instance['form_id'] = ( !empty( $new_instance['form_id'] ) ) ? $new_instance['form_id'] : ''; 

        return $instance;
    }
 
}