<?php

/**
 * Functions for Mailchimp
 */

use DrewM\MailChimp\MailChimp;

/**
 * Get MailChimp lists from the cache
 * If the cache has expired, get them with the MailChimp API
 * @return array Array of all lists
 */
function mwp_get_mailchimp_lists(){

	if ( false === ( $lists = get_transient( 'mwp_mailchimp_lists' ) ) ) {
		$api_key = get_option( 'mwp_mailchimp_api_key', false );
		$lists = array();

		if( $api_key ) {
			$MailChimp = new MailChimp( $api_key );
			$lists_retrieved = $MailChimp->get('lists');
			foreach ($lists_retrieved['lists'] as $list) {
				$lists[ $list[ 'id' ] ] = $list[ 'name' ];
			}
		}
		
		set_transient( 'mwp_mailchimp_lists', $lists );
	}

	return $lists;
}

/**
 * Deletes the transient for MailChimp lists and 
 * gets the lists from the MailChimp
 */
function mwp_refresh_mailchimp_lists() {
	delete_transient( 'mwp_mailchimp_lists' );
	
	$result = array();

	try {
		mwp_get_mailchimp_lists();
		$result['success'] = 1;
		$result['message'] = __( 'MailChimp Lists Refreshed.', 'mwp' );
	} catch (Exception $e) {
		$result['success'] = 0;
		$result['message'] = $e->getMessage();
	}	

	return $result;
}

/**
 * Subscribe the user to a list
 * When this function is called, we have already checked everything
 * @param  number $list_id 
 * @param  string $name    
 * @param  string $email   
 * @return mixed  True if it's a new one or a subscribed one, if not the result array          
 */
function mwp_subscribe_user_to_list( $list_id, $name, $email ) {
	$api_key = get_option( 'mwp_mailchimp_api_key', false );

	if( $api_key ) {
		$MailChimp = new MailChimp( $api_key );
		$result = $MailChimp->post("lists/" . $list_id . "/members", array(
                'email_address' => $email,
                'status'        => 'pending', // We want them to confirm
                'merge_fields' => array( 'FNAME' => $name )
        ));
        
        // New subscriber
		if( isset( $result['id'] ) && isset( $result['email_address'] ) ) {
			return true;
		}

		if( isset( $result[ 'title' ] ) && $result[ 'title' ] == 'Member Exists' ) {
			return true;
		}

		return $result;
	}

	return false;
}