<?php

/**
 * Settings for MailChimp WordPress Plugin
 * In this file we are creating the settings page for MWP
 */

/**
 * Create an options page
 */
function mwp_settings() {
	add_options_page( 
		'MWP',
		'MWP',
		'manage_options',
		'mwp-settings',
		'mwp_settings_page'
	);
}

/**
 * Custom Settings Page
 */
function mwp_settings_page(){
	if( isset( $_POST['mwp_save_options'] ) ) {
		$mwp_mailchimp_api_key = $_POST['mwp_mailchimp_api_key'];
		update_option( 'mwp_mailchimp_api_key', $mwp_mailchimp_api_key );

		?>
		<div id="message" class="updated notice notice-success is-dismissible">
			<p><?php _e( 'Settings saved.', 'mwp' ); ?></p>
			<button type="button" class="notice-dismiss">
				<span class="screen-reader-text"><?php _e( 'Dismiss this notice.', 'mwp'); ?></span>
			</button>
		</div>
		<?php
	}

	if( isset( $_POST['mwp_reset_lists'] ) ) {
		
		$result = mwp_refresh_mailchimp_lists();
		$notice_class = 'updated';
		$message = $result['message'];
		if( ! $result['success'] ) {
			$notice_class = 'error';
		}
		?>
		<div id="message" class="<?php echo $notice_class; ?> notice is-dismissible">
			<p><?php echo $message; ?></p>
			<button type="button" class="notice-dismiss">
				<span class="screen-reader-text"><?php _e( 'Dismiss this notice.', 'mwp'); ?></span>
			</button>
		</div>
		<?php
	}

	$mwp_mailchimp_api_key = get_option( 'mwp_mailchimp_api_key', '' );
	?>
	<div class="wrap">
		<h1><?php _e( 'MWP', 'mwp' ); ?></h1>
		<p class="description"><?php _e( 'Settings for MWP', 'mwp' ); ?></p>
		<form action="" method="POST">
			<table class="form-table">
	            <tr>
	                <th>
	                    <?php _e( 'MailChimp API key', 'mwp'); ?>
	                </th>
	                <td>
	                     <input class="widefat" name="mwp_mailchimp_api_key" type="text" placeholder="<?php _e( 'Enter your MailChimp API key', 'mwp'); ?>" value="<?php echo $mwp_mailchimp_api_key; ?>" />
	               		<p class="description"><?php _e( 'API Keys can be found or created in Mailchimp under Account > Extras > API Keys', 'mwp' ); ?></p>
	                </td>
	            </tr> 
	        </table>
	        <button type="submit" name="mwp_save_options" class="button button-primary"><?php _e( 'Save Changes', 'mwp' ); ?></button>
	        <button type="submit" name="mwp_reset_lists" class="button button-secondary"><?php _e( 'Refresh Lists', 'mwp' ); ?></button>
    	</form>
	</div>
	<?php
}